% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kplaces.R
\name{kplaces}
\alias{kplaces}
\title{k-places}
\format{
The input format must be a data frame in a two-mode edgelist structure. \cr
Data frame can contain other variables, relevant columns will be selected in \emph{Arguments} parameters. Missing values, empty cells and repeated pairs (Element-Set) will be deleted for analysis.
}
\usage{
kplaces(data, col.elements, col.sets, k)
}
\arguments{
\item{data}{The input data frame. Data must be in a two-mode edgelist structure}

\item{col.elements}{The name of the column of elements}

\item{col.sets}{The name of the column of sets}

\item{k}{A natural number that indicates the tolerance level}
}
\value{
The output is a list with four data frames:

\itemize{\item The original two columns data frame and the column "k_places" with k-places and places labels'
\item A data frame containing information about places and k-places.\cr
"PlaceLabel" contains places and k-places labels. Places labels start with \emph{P}, followed by the place number, the number of elements in place and the number of sets defining place. K-Places labels start with \emph{P}, followed by the k-place number, an \emph{*}, the number of elements in k-place, the number of all sets defining the k-place,the number of sets in common among the merged places, and the value of \emph{k} \cr
"NbElements" contains the number of elements in the place / k-place \cr
"NbSets" contains the number of sets defining the place / k-place \cr
"PlaceDetail" contains the name of all the elements in the place /k-place and all the sets defining the place / k-place
\item A data frame with the relation of places merged to k-places and the sets in common
\item The network of places in a two-mode edgelist format }
}
\description{
Execute a structural equivalence analysis in bipartite graphs allowing a \emph{k} tolerance level
}
\details{
A k-place is a place (a position of structural equivalence) which allows a maximum divergence of \emph{k} sets that define the place. Compared with \code{\link{places}}, \emph{k-places} are a less restrictive way of identifying positions of structural equivalence. This function identifies places and k-places, and a network of places and k-places is created.\cr
A network of k-places is defined as a collection of k-places and places linked by sharing sets. A pair of k-places and/or places are linked if they are defined by at least one set in common. A network of k-places, as a blockmodel image, is a network of structurally equivalent positions.\cr
The k-places will not be identified for cases with k sets or less.\cr
The ambiguous cases are reported as messages in the R console. An ambiguous case is a subset of more than two places where the dyads can be a k-place but not all the subset. For example, for k=1, the place P1 defined by the sets {A, B} can be a k-place with P2{A, B, C} or with P3{A, B, D}, but the k-place formed by the three places is not correct because P2 and P3 are divergent in more than k sets (specifically, the sets C and D)
}
\examples{
# Load example dataset
data(fooA)

# Compute kplaces
Result <- kplaces(data = fooA, col.elements = "Actors", col.sets = "Groups", k = 1)
Result <- kplaces(fooA, "Actors", "Groups", 1)
}
\references{
The use of k-places is suggested in: \cr
Lucena, D. (2020). Beyond the Dyadic Approach in Social Network Analysis: Applications to Innovation Studies and Financial Economics (Doctoral dissertation).
}
\author{
Delio Lucena Piquero (\href{http://lereps.sciencespo-toulouse.fr/}{LEREPS} - University of Toulouse) <delio.lucena@ut-capitole.fr>
}
